aboutsummaryrefslogtreecommitdiffstats
path: root/archetype
diff options
context:
space:
mode:
Diffstat (limited to 'archetype')
-rw-r--r--archetype/src/main/resources/archetype-resources/pom.xml37
-rw-r--r--archetype/src/main/resources/archetype-resources/src/test/java/__artifactId__/client/__projectName__Test.java4
2 files changed, 38 insertions, 3 deletions
diff --git a/archetype/src/main/resources/archetype-resources/pom.xml b/archetype/src/main/resources/archetype-resources/pom.xml
index 3826e2ea..dbec1ee7 100644
--- a/archetype/src/main/resources/archetype-resources/pom.xml
+++ b/archetype/src/main/resources/archetype-resources/pom.xml
@@ -12,7 +12,7 @@
<maven.compiler.source>1.5</maven.compiler.source>
<maven.compiler.target>1.5</maven.compiler.target>
<gQueryVersion>1.0.0-SNAPSHOT</gQueryVersion>
- <gwtversion>2.0.3</gwtversion>
+ <gwtversion>2.0.4</gwtversion>
</properties>
<repositories>
@@ -45,6 +45,24 @@
</dependency>
<dependency>
<groupId>com.google.gwt</groupId>
+ <artifactId>gwt-user</artifactId>
+ <version>${gwtversion}</version>
+ <scope>provided</scope>
+ </dependency>
+ <dependency>
+ <groupId>com.google.gwt</groupId>
+ <artifactId>gwt-dev</artifactId>
+ <version>${gwtversion}</version>
+ <scope>provided</scope>
+ </dependency>
+ <dependency>
+ <groupId>com.google.gwt</groupId>
+ <artifactId>gwt-servlet</artifactId>
+ <version>${gwtversion}</version>
+ <scope>runtime</scope>
+ </dependency>
+ <dependency>
+ <groupId>com.google.gwt</groupId>
<artifactId>gwtquery</artifactId>
<version>${gQueryVersion}</version>
<scope>provided</scope>
@@ -73,6 +91,23 @@
</executions>
</plugin>
<plugin>
+ <artifactId>maven-surefire-plugin</artifactId>
+ <configuration>
+ <additionalClasspathElements>
+ <additionalClasspathElement>\${project.build.sourceDirectory}</additionalClasspathElement>
+ <additionalClasspathElement>\${project.build.testSourceDirectory}</additionalClasspathElement>
+ </additionalClasspathElements>
+ <useManifestOnlyJar>false</useManifestOnlyJar>
+ <forkMode>always</forkMode>
+ <systemProperties>
+ <property>
+ <name>gwt.args</name>
+ <value>-out target/www</value>
+ </property>
+ </systemProperties>
+ </configuration>
+ </plugin>
+ <plugin>
<artifactId>maven-clean-plugin</artifactId>
<configuration>
<filesets>
diff --git a/archetype/src/main/resources/archetype-resources/src/test/java/__artifactId__/client/__projectName__Test.java b/archetype/src/main/resources/archetype-resources/src/test/java/__artifactId__/client/__projectName__Test.java
index 129f1fea..7ba9d631 100644
--- a/archetype/src/main/resources/archetype-resources/src/test/java/__artifactId__/client/__projectName__Test.java
+++ b/archetype/src/main/resources/archetype-resources/src/test/java/__artifactId__/client/__projectName__Test.java
@@ -11,7 +11,7 @@ import com.google.gwt.query.client.plugins.Effects.Speed;
import com.google.gwt.user.client.Event;
import com.google.gwt.user.client.Timer;
/**
* Test class for ${projecName} entry-point
*/
public class ${projectName}Test extends GWTTestCase {
@@ -29,7 +29,7 @@ public class ${projectName}Test extends GWTTestCase {
final GQuery g = $("<div></div>").appendTo(document);
// run onModuleLoad
- Art a = new Art();
+ ${projectName} a = new ${projectName}();
a.onModuleLoad();
// delay the test
@@ -11,7 +11,7 @@ import com.google.gwt.query.client.plugins.Effects.Speed;
import com.google.gwt.user.client.Timer;
/**
- * Test class for ${projecName} entry-point
+ * Test class for ${projectName} entry-point
*/
public class ${projectName}Test extends GWTTestCase {